/* eslint-disable no-restricted-imports */
import { z } from "zod";

export const requestBodySchema = z.object({
	stage: z.string({
		required_error: "stage is required",
		invalid_type_error: "stage must be a string"
	}),
	type: z.string({
		required_error: "type is required",
		invalid_type_error: "type must be a string"
	}),
	taskId: z.number({
		required_error: "taskId is required",
		invalid_type_error: "taskId must be a number"
	})
});

export const updateRequestBodySchema = z.object({
	stage: z.string({
		required_error: "stage is required",
		invalid_type_error: "stage must be a string"
	})
});

export const workflowPathParamsSchema = z.number({
	required_error: "workflowId is required",
	invalid_type_error: "workflowId must be a number"
});

export const approverBodySchema = z.object({
	approverId: z.number({
		required_error: "approverId is required",
		invalid_type_error: "approverId must be a number",
		description: "This is the user id of the approver"
	}),
	approverType: z.enum(["role", "user"], {
		required_error: "approverType is required",
		invalid_type_error: "approverType must be a either role or user"
	})
});

export const assignBodySchema = z.object({
	assigneeId: z.number({
		required_error: "assigneeId is required",
		invalid_type_error: "assigneeId must be a number",
		description: "This is the user id of the assignee"
	}),
	assigneeType: z.enum(["role", "user"], {
		required_error: "assigneeType is required",
		invalid_type_error: "assigneeType must be a either role or user"
	})
});

export const singleEntrySchema = z.object({
	target_id: z.number({
		required_error: "target_id is required",
		invalid_type_error: "target_id must be a number"
	}),
	target_type: z.string({
		required_error: "target_type is required",
		invalid_type_error: "target_type must be a string"
	})
});

export const idPathParams = z.number({
	required_error: "id is required",
	invalid_type_error: "id must be a number"
});
